require("map")
require("snake")
require("food")
require("collision")
require("menu")

function love.load()
	medium = love.graphics.newFont(45)
	
	speed_index = 3
	speed = {0.06, 0.08, 0.1}
	
	gamestate = "menu"
	direction = "none"
	
	width, height = love.window.getDimensions() -- get the width and height of the window to create the game grid on any power of 2 window size.
	
	-- *Settings for snake parameters* -- 
	snake = { -- an array of snake segment coordinates
		{x= 256, y = 256}
	}
	snake_width = 16
	snake_height = 16
	snake_speed = speed[speed_index] -- smaller number means faster snake, recommend not going below 0.04
	
	-- *Table used to keep track of snake coordinates with available_map in map.lua* --
	snake_coords_clear = {}
	for y=1, height/16 do
		for x=1, width/16 do
			table.insert(snake_coords_clear, {x*16,y*16})
		end
	end
	
	love.graphics.setBackgroundColor(0, 0, 0)
	food = {}
	available_map()
	food_position()
	snakeDelay = 0
	walls = false
	
	if speed_index == 1 then
		speed_message = "Snake Speed: Fast"
	elseif speed_index == 2 then
		speed_message = "Snake Speed: Medium"
	else
		speed_message = "Snake Speed: Slow"
	end
		
	menu_button_spawn(width*0.25, height*0.26, "Start Game", "start")
	menu_button_spawn(width*0.31, height*0.45, "Options", "options")
	menu_button_spawn(width*0.38, height*0.65, "Quit", "quit")
	
	if walls == true then
		walls_message = "Walls Enabled: True"
	else
		walls_message = "Walls Enabled: False"
	end
	
	options_button_spawn(width*0.01, height*0.2, speed_message, "speed")
	options_button_spawn(width*0.04, height*0.45, walls_message, "walls")
	options_button_spawn(width*0.2, height*0.7, "Back to Menu", "menu_return")
	
	paused_button_spawn(width*0.25, height*0.35, "Continue Playing", "continue")
	paused_button_spawn(width*0.25, height*0.7, "Return to Menu", "menu")
end

function love.update(dt)
	mousex = love.mouse.getX()
	mousey = love.mouse.getY()
	if gamestate == "playing" then
		available_map()
		check_collision()
		key_check()
		if direction ~= "none" then
			snakeDelay = snakeDelay + dt
		end
		
		if snakeDelay >= snake_speed then     -- Important, so that the snake isn't moving too quickly
			snake_move(dt)
			snakeDelay = 0
		end
		
	else
		button_check()
	end
end

function love.draw()
	 -- DEBUG love.graphics.print("gamestate=" .. gamestate, 50, 50)
	if gamestate == "playing" then
		map_draw()
		snake_draw()
		if direction ~= "none" then
			food_draw()
		end
		-- DEBUG love.graphics.print(tostring(#snake).. " x=" .. tostring(snake[1].x) .. " y=" .. tostring(snake[1].y) .. , 50, 50)
	else
		button_draw()
	end
end

function love.mousepressed(x, y)
	if gamestate ~= "playing" then
		button_click(x, y)
	end
end

function key_check()

	if love.keyboard.isDown("up") then
		direction = "up"
	elseif love.keyboard.isDown("down") then
		direction = "down"
	elseif love.keyboard.isDown("left") then
		direction = "left"	
	elseif love.keyboard.isDown("right") then
		direction = "right"
	elseif love.keyboard.isDown("escape") then
		gamestate = "paused"
	end
	
end


